@@ -75,6 +75,10 @@ impl Default for KeymapConfig {
                     key_sequence: "_".into(),
                     command: Command::Mute,
                 },
+                Keymap {
+                    key_sequence: "0".into(),
+                    command: Command::SeekStart,
+                },
                 Keymap {
                     key_sequence: ">".into(),
                     command: Command::SeekForward { duration: None },
@@ -123,6 +127,10 @@ impl Default for KeymapConfig {
                     key_sequence: "a".into(),
                     command: Command::ShowActionsOnCurrentTrack,
                 },
+                Keymap {
+                    key_sequence: "A".into(),
+                    command: Command::ShowActionsOnCurrentContext,
+                },
                 #[cfg(feature = "streaming")]
                 Keymap {
                     key_sequence: "R".into(),
@@ -268,10 +276,6 @@ impl Default for KeymapConfig {
                     key_sequence: "g g".into(),
                     command: Command::SelectFirstOrScrollToTop,
                 },
-                Keymap {
-                    key_sequence: "home".into(),
-                    command: Command::SelectFirstOrScrollToTop,
-                },
                 Keymap {
                     key_sequence: "G".into(),
                     command: Command::SelectLastOrScrollToBottom,
